@@ -23,6 +23,8 @@ function(i, v, dim = NULL, dimnames = NULL)
     ## which are either NULL or character vectors as long as the
     ## corresponding dim.
     ## </FIXME>
+    if(anyDuplicated(i) > 0)
+        stop("Duplicate rows in i are not allowed.")
     ssa <- list(i = i, v = v, dim = as.integer(dim), dimnames = dimnames)
     class(ssa) <- "simple_sparse_array"
     ## Note that this should never be true as it implies that either
@@ -216,7 +218,7 @@ function(x, ...)
 		return(vector(mode = typeof(x$v), length = 0L))
 	     ## Ignore dimensions. 
 	     if(ncol(i) != nd || !is.numeric(i)) 
-		return(do.call("[.simple_sparse_array", 
+		return(do.call(`[.simple_sparse_array`, 
 			       list(x = x, as.vector(i))))
 	    if(is.double(i))
 		i <- trunc(i)
@@ -290,7 +292,7 @@ function(x, ...)
             }
         }
         if(!is.null(dnx <- x$dimnames))
-            dnx[] <- Map("[", dnx, ind)
+            dnx[] <- Map(`[`, dnx, ind)
         out <- simple_sparse_array(x$i[pos, , drop = FALSE], x$v[pos],
                                    dx, dnx)
     }
